@@ -50,21 +50,11 @@ typedef struct {
 	char        *save_uri;
 	gboolean     is_tmp;
 
-	GtkActionGroup *action_group;
-	guint ui_merge_id;
+	GSimpleAction *action;
 } TotemSaveFilePluginPrivate;
 
 TOTEM_PLUGIN_REGISTER(TOTEM_TYPE_SAVE_FILE_PLUGIN, TotemSaveFilePlugin, totem_save_file_plugin)
 
-static void totem_save_file_plugin_copy (GtkAction *action,
-					 TotemSaveFilePlugin *pi);
-
-static GtkActionEntry totem_save_file_plugin_actions [] = {
-	{ "SaveFile", "save-as", N_("Save a Copy..."), "<Ctrl>S",
-		N_("Save a copy of the movie"),
-		G_CALLBACK (totem_save_file_plugin_copy) },
-};
-
 static void
 copy_uris_with_nautilus (const char *source,
 			 const char *src_name,
@@ -116,7 +106,8 @@ copy_uris_with_nautilus (const char *source,
 }
 
 static void
-totem_save_file_plugin_copy (GtkAction *action,
+totem_save_file_plugin_copy (GSimpleAction       *action,
+			     GVariant            *parameter,
 			     TotemSaveFilePlugin *pi)
 {
 	GtkWidget *fs;
@@ -125,12 +116,11 @@ totem_save_file_plugin_copy (GtkAction *action,
 
 	g_assert (pi->priv->mrl != NULL);
 
-
 	fs = gtk_file_chooser_dialog_new (_("Save a Copy"),
-					  totem_get_main_window (pi->priv->totem),
+					  totem_object_get_main_window (pi->priv->totem),
 					  GTK_FILE_CHOOSER_ACTION_SAVE,
-					  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					  GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+					  _("_Cancel"), GTK_RESPONSE_CANCEL,
+					  _("_Save"), GTK_RESPONSE_ACCEPT,
 					  NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (fs), GTK_RESPONSE_ACCEPT);
 	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (fs), FALSE);
@@ -194,15 +184,10 @@ static void
 totem_save_file_file_closed (TotemObject *totem,
 				 TotemSaveFilePlugin *pi)
 {
-	GtkAction *action;
+	g_clear_pointer (&pi->priv->mrl, g_free);
+	g_clear_pointer (&pi->priv->name, g_free);
 
-	g_free (pi->priv->mrl);
-	pi->priv->mrl = NULL;
-	g_free (pi->priv->name);
-	pi->priv->name = NULL;
-
-	action = gtk_action_group_get_action (pi->priv->action_group, "SaveFile");
-	gtk_action_set_sensitive (action, FALSE);
+	g_simple_action_set_enabled (G_SIMPLE_ACTION (pi->priv->action), FALSE);
 }
 
 static void
@@ -210,25 +195,17 @@ totem_save_file_file_opened (TotemObject *totem,
 			     const char *mrl,
 			     TotemSaveFilePlugin *pi)
 {
-	TotemSaveFilePluginPrivate *priv = pi->priv;
-	GtkAction *action;
-
-	if (pi->priv->mrl != NULL) {
-		g_free (pi->priv->mrl);
-		pi->priv->mrl = NULL;
-		g_free (pi->priv->name);
-		pi->priv->name = NULL;
-	}
+	g_clear_pointer (&pi->priv->mrl, g_free);
+	g_clear_pointer (&pi->priv->name, g_free);
 
 	if (mrl == NULL)
 		return;
 
 	if (g_str_has_prefix (mrl, "file:") || g_str_has_prefix (mrl, "smb:")) {
 		/* We can always copy files from file:/// URIs */
-		action = gtk_action_group_get_action (priv->action_group, "SaveFile");
-		gtk_action_set_sensitive (action, TRUE);
+		g_simple_action_set_enabled (G_SIMPLE_ACTION (pi->priv->action), TRUE);
 		pi->priv->mrl = g_strdup (mrl);
-		pi->priv->name = totem_get_short_title (pi->priv->totem);
+		pi->priv->name = totem_object_get_short_title (pi->priv->totem);
 		pi->priv->is_tmp = FALSE;
 	}
 }
@@ -238,7 +215,6 @@ totem_save_file_download_filename (GObject    *gobject,
 				   GParamSpec *pspec,
 				   TotemSaveFilePlugin *pi)
 {
-	GtkAction *action;
 	char *filename;
 
 	/* We're already ready to copy it */
@@ -252,11 +228,10 @@ totem_save_file_download_filename (GObject    *gobject,
 
 	pi->priv->mrl = g_filename_to_uri (filename, NULL, NULL);
 	g_free (filename);
-	pi->priv->name = totem_get_short_title (pi->priv->totem);
+	pi->priv->name = totem_object_get_short_title (pi->priv->totem);
 	pi->priv->is_tmp = TRUE;
 
-	action = gtk_action_group_get_action (pi->priv->action_group, "SaveFile");
-	gtk_action_set_sensitive (action, TRUE);
+	g_simple_action_set_enabled (G_SIMPLE_ACTION (pi->priv->action), TRUE);
 }
 
 static void
@@ -264,8 +239,8 @@ impl_activate (PeasActivatable *plugin)
 {
 	TotemSaveFilePlugin *pi = TOTEM_SAVE_FILE_PLUGIN (plugin);
 	TotemSaveFilePluginPrivate *priv = pi->priv;
-	GtkUIManager *uimanager = NULL;
-	GtkAction *action;
+	GMenu *menu;
+	GMenuItem *item;
 	char *path;
 	char *mrl;
 
@@ -276,7 +251,7 @@ impl_activate (PeasActivatable *plugin)
 	g_free (path);
 
 	priv->totem = g_object_get_data (G_OBJECT (plugin), "object");
-	priv->bvw = totem_get_video_widget (priv->totem);
+	priv->bvw = totem_object_get_video_widget (priv->totem);
 
 	g_signal_connect (priv->totem,
 			  "file-opened",
@@ -291,39 +266,27 @@ impl_activate (PeasActivatable *plugin)
 			  G_CALLBACK (totem_save_file_download_filename),
 			  plugin);
 
+	priv->action = g_simple_action_new ("save-as", NULL);
+	g_signal_connect (G_OBJECT (priv->action), "activate",
+			  G_CALLBACK (totem_save_file_plugin_copy), plugin);
+	g_action_map_add_action (G_ACTION_MAP (priv->totem), G_ACTION (priv->action));
+	gtk_application_add_accelerator (GTK_APPLICATION (priv->totem),
+					 "<Primary>S",
+					 "app.save-as",
+					 NULL);
+	/* FIXME: https://bugzilla.gnome.org/show_bug.cgi?id=695917
+	gtk_application_add_accelerator (GTK_APPLICATION (priv->totem),
+					 "Save",
+					 "app.save-as",
+					 NULL); */
+
 	/* add UI */
-	priv->action_group = gtk_action_group_new ("SaveFileActions");
-	gtk_action_group_set_translation_domain (priv->action_group, GETTEXT_PACKAGE);
-	gtk_action_group_add_actions (priv->action_group,
-				      totem_save_file_plugin_actions,
-				      G_N_ELEMENTS (totem_save_file_plugin_actions),
-				      pi);
+	menu = totem_object_get_menu_section (priv->totem, "save-placeholder");
+	item = g_menu_item_new (_("Save a Copy..."), "app.save-as");
+	g_menu_item_set_attribute (item, "accel", "s", "<Primary>s");
+	g_menu_append_item (G_MENU (menu), item);
 
-	uimanager = totem_get_ui_manager (priv->totem);
-	gtk_ui_manager_insert_action_group (uimanager, priv->action_group, -1);
-	g_object_unref (priv->action_group);
-
-	priv->ui_merge_id = gtk_ui_manager_new_merge_id (uimanager);
-
-	gtk_ui_manager_add_ui (uimanager,
-			       priv->ui_merge_id,
-			       "/ui/tmw-menubar/movie/save-placeholder",
-			       "SaveFile",
-			       "SaveFile",
-			       GTK_UI_MANAGER_MENUITEM,
-			       TRUE);
-	gtk_ui_manager_add_ui (uimanager,
-			       priv->ui_merge_id,
-			       "/ui/totem-main-popup/save-placeholder",
-			       "SaveFile",
-			       "SaveFile",
-			       GTK_UI_MANAGER_MENUITEM,
-			       TRUE);
-
-	action = gtk_action_group_get_action (priv->action_group, "SaveFile");
-	gtk_action_set_sensitive (action, FALSE);
-
-	mrl = totem_get_current_mrl (priv->totem);
+	mrl = totem_object_get_current_mrl (priv->totem);
 	totem_save_file_file_opened (priv->totem, mrl, pi);
 	totem_save_file_download_filename (NULL, NULL, pi);
 	g_free (mrl);
@@ -334,23 +297,17 @@ impl_deactivate (PeasActivatable *plugin)
 {
 	TotemSaveFilePlugin *pi = TOTEM_SAVE_FILE_PLUGIN (plugin);
 	TotemSaveFilePluginPrivate *priv = pi->priv;
-	GtkUIManager *uimanager = NULL;
 
 	g_signal_handlers_disconnect_by_func (priv->totem, totem_save_file_file_opened, plugin);
 	g_signal_handlers_disconnect_by_func (priv->totem, totem_save_file_file_closed, plugin);
 	g_signal_handlers_disconnect_by_func (priv->bvw, totem_save_file_download_filename, plugin);
 
-	uimanager = totem_get_ui_manager (priv->totem);
-	gtk_ui_manager_remove_ui (uimanager, priv->ui_merge_id);
-	gtk_ui_manager_remove_action_group (uimanager, priv->action_group);
+	totem_object_empty_menu_section (priv->totem, "save-placeholder");
 
 	priv->totem = NULL;
 	priv->bvw = NULL;
 
-	g_free (priv->mrl);
-	priv->mrl = NULL;
-	g_free (priv->name);
-	priv->name = NULL;
-	g_free (priv->save_uri);
-	priv->save_uri = NULL;
+	g_clear_pointer (&pi->priv->mrl, g_free);
+	g_clear_pointer (&pi->priv->name, g_free);
+	g_clear_pointer (&pi->priv->save_uri, g_free);
 }
