@@ -49,52 +49,33 @@
 typedef struct {
 	TotemObject *totem;
 	BaconVideoWidget *bvw;
-	GSettings *settings;
 
+	gboolean       inhibit_available;
 	guint          handler_id_playing;
-	guint          handler_id_metadata;
 	guint          inhibit_cookie;
+	guint          uninhibit_timeout;
 } TotemScreensaverPluginPrivate;
 
 TOTEM_PLUGIN_REGISTER(TOTEM_TYPE_SCREENSAVER_PLUGIN,
 		      TotemScreensaverPlugin,
 		      totem_screensaver_plugin)
 
-static gboolean
-has_video (BaconVideoWidget *bvw)
-{
-	GValue value = { 0, };
-	gboolean ret;
-
-	bacon_video_widget_get_metadata (bvw, BVW_INFO_HAS_VIDEO, &value);
-	ret = g_value_get_boolean (&value);
-	g_value_unset (&value);
-
-	return ret;
-}
-
 static void
 totem_screensaver_update_from_state (TotemObject *totem,
 				     TotemScreensaverPlugin *pi)
 {
-	gboolean lock_screensaver_on_audio, has_video_frames;
-	BaconVideoWidget *bvw;
-
-	bvw = BACON_VIDEO_WIDGET (totem_get_video_widget ((Totem *)(totem)));
-
-	lock_screensaver_on_audio = g_settings_get_boolean (pi->priv->settings, "lock-screensaver-on-audio");
-	has_video_frames = has_video (bvw);
-
-	if ((totem_is_playing (totem) != FALSE && has_video_frames) ||
-	    (totem_is_playing (totem) != FALSE && !lock_screensaver_on_audio)) {
-		if (pi->priv->inhibit_cookie == 0) {
+	if (totem_object_is_playing (totem) != FALSE) {
+		if (pi->priv->inhibit_cookie == 0 &&
+		    pi->priv->inhibit_available) {
 			GtkWindow *window;
 
-			window = totem_get_main_window (totem);
+			window = totem_object_get_main_window (totem);
 			pi->priv->inhibit_cookie = gtk_application_inhibit (GTK_APPLICATION (totem),
 										window,
 										GTK_APPLICATION_INHIBIT_IDLE,
 										_("Playing a movie"));
+			if (pi->priv->inhibit_cookie == 0)
+				pi->priv->inhibit_available = FALSE;
 			g_object_unref (window);
 		}
 	} else {
@@ -105,46 +86,47 @@ totem_screensaver_update_from_state (TotemObject *totem,
 	}
 }
 
+static gboolean
+uninhibit_timeout_cb (TotemScreensaverPlugin *pi)
+{
+	totem_screensaver_update_from_state (pi->priv->totem, pi);
+	pi->priv->uninhibit_timeout = 0;
+	return G_SOURCE_REMOVE;
+}
+
 static void
 property_notify_cb (TotemObject *totem,
 		    GParamSpec *spec,
 		    TotemScreensaverPlugin *pi)
 {
+	if (pi->priv->uninhibit_timeout != 0) {
+		g_source_remove (pi->priv->uninhibit_timeout);
+		pi->priv->uninhibit_timeout = 0;
+	}
+
+	if (totem_object_is_playing (totem) == FALSE) {
+		pi->priv->uninhibit_timeout = g_timeout_add_seconds (5, (GSourceFunc) uninhibit_timeout_cb, pi);
+		return;
+	}
+
 	totem_screensaver_update_from_state (totem, pi);
 }
 
-static void
-got_metadata_cb (BaconVideoWidget *bvw, TotemScreensaverPlugin *pi)
-{
-	totem_screensaver_update_from_state (pi->priv->totem, pi);
-}
-
-static void
-lock_screensaver_on_audio_changed_cb (GSettings *settings, const gchar *key, TotemScreensaverPlugin *pi)
-{
-	totem_screensaver_update_from_state (pi->priv->totem, pi);
-}
-
 static void
 impl_activate (PeasActivatable *plugin)
 {
 	TotemScreensaverPlugin *pi = TOTEM_SCREENSAVER_PLUGIN (plugin);
 	TotemObject *totem;
 
-	totem = g_object_get_data (G_OBJECT (plugin), "object");
-	pi->priv->bvw = BACON_VIDEO_WIDGET (totem_get_video_widget (totem));
+	pi->priv->inhibit_available = TRUE;
 
-	pi->priv->settings = g_settings_new (TOTEM_GSETTINGS_SCHEMA);
-	g_signal_connect (pi->priv->settings, "changed::lock-screensaver-on-audio", (GCallback) lock_screensaver_on_audio_changed_cb, plugin);
+	totem = g_object_get_data (G_OBJECT (plugin), "object");
+	pi->priv->bvw = BACON_VIDEO_WIDGET (totem_object_get_video_widget (totem));
 
 	pi->priv->handler_id_playing = g_signal_connect (G_OBJECT (totem),
 						   "notify::playing",
 						   G_CALLBACK (property_notify_cb),
 						   pi);
-	pi->priv->handler_id_metadata = g_signal_connect (G_OBJECT (pi->priv->bvw),
-						    "got-metadata",
-						    G_CALLBACK (got_metadata_cb),
-						    pi);
 
 	pi->priv->totem = g_object_ref (totem);
 
@@ -157,17 +139,16 @@ impl_deactivate	(PeasActivatable *plugin)
 {
 	TotemScreensaverPlugin *pi = TOTEM_SCREENSAVER_PLUGIN (plugin);
 
-	g_object_unref (pi->priv->settings);
-
 	if (pi->priv->handler_id_playing != 0) {
 		TotemObject *totem;
 		totem = g_object_get_data (G_OBJECT (plugin), "object");
 		g_signal_handler_disconnect (G_OBJECT (totem), pi->priv->handler_id_playing);
 		pi->priv->handler_id_playing = 0;
 	}
-	if (pi->priv->handler_id_metadata != 0) {
-		g_signal_handler_disconnect (G_OBJECT (pi->priv->bvw), pi->priv->handler_id_metadata);
-		pi->priv->handler_id_metadata = 0;
+
+	if (pi->priv->uninhibit_timeout != 0) {
+		g_source_remove (pi->priv->uninhibit_timeout);
+		pi->priv->uninhibit_timeout = 0;
 	}
 
 	if (pi->priv->inhibit_cookie != 0) {
