@@ -14,8 +14,7 @@
  *
  *  You should have received a copy of the GNU Library General Public
  *  License along with the Gnome Library; see the file COPYING.LIB.  If not,
- *  write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301  USA.
+ *  see <http://www.gnu.org/licenses/>.
  *
  *  Author: Bastien Nocera <hadess@hadess.net>
  * 
@@ -54,7 +53,7 @@ totem_interface_error_dialog (const char *title, const char *reason,
 	GtkWidget *error_dialog;
 
 	if (reason == NULL)
-		g_warning ("totem_action_error called with reason == NULL");
+		g_warning ("%s called with reason == NULL", G_STRFUNC);
 
 	error_dialog =
 		gtk_message_dialog_new (NULL,
