@@ -34,6 +34,7 @@
 #include <stdio.h>
 #include <sys/stat.h>
 #include <sys/types.h>
+#include <libpeas-gtk/peas-gtk-plugin-manager.h>
 
 #include "bacon-video-widget-enums.h"
 #include "totem.h"
@@ -49,7 +50,6 @@
 
 /* Callback functions for GtkBuilder */
 G_MODULE_EXPORT void checkbutton2_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
-G_MODULE_EXPORT void audio_screensaver_button_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
 G_MODULE_EXPORT void visual_menu_changed (GtkComboBox *combobox, Totem *totem);
 G_MODULE_EXPORT void tpw_color_reset_clicked_cb (GtkButton *button, Totem *totem);
 G_MODULE_EXPORT void font_set_cb (GtkFontButton * fb, Totem * totem);
@@ -84,15 +84,6 @@ checkbutton2_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
 	totem_prefs_set_show_visuals (totem, value);
 }
 
-void
-audio_screensaver_button_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
-{
-	gboolean value;
-
-	value = gtk_toggle_button_get_active (togglebutton);
-	g_settings_set_boolean (totem->settings, "lock-screensaver-on-audio", value);
-}
-
 static void
 show_vfx_changed_cb (GSettings *settings, const gchar *key, TotemObject *totem)
 {
@@ -114,28 +105,6 @@ disable_kbd_shortcuts_changed_cb (GSettings *settings, const gchar *key, TotemOb
 	totem->disable_kbd_shortcuts = g_settings_get_boolean (totem->settings, "disable-keyboard-shortcuts");
 }
 
-static void
-lock_screensaver_on_audio_changed_cb (GSettings *settings, const gchar *key, TotemObject *totem)
-{
-	GObject *item, *radio;
-	gboolean value;
-
-	item = POBJ ("tpw_audio_toggle_button");
-	g_signal_handlers_disconnect_by_func (item,
-					      audio_screensaver_button_toggled_cb, totem);
-
-	value = g_settings_get_boolean (totem->settings, "lock-screensaver-on-audio");
-	if (value != FALSE) {
-		radio = POBJ ("tpw_audio_toggle_button");
-	} else {
-		radio = POBJ ("tpw_video_toggle_button");
-	}
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radio), TRUE);
-
-	g_signal_connect (item, "toggled",
-			  G_CALLBACK (audio_screensaver_button_toggled_cb), totem);
-}
-
 void
 visual_menu_changed (GtkComboBox *combobox, Totem *totem)
 {
@@ -263,15 +232,67 @@ visualization_quality_writable_changed_cb (GSettings *settings, const gchar *key
 	gtk_widget_set_sensitive (PWID ("tpw_visuals_size_combobox"), writable && show_visualizations);
 }
 
+static gboolean
+totem_plugins_window_delete_cb (GtkWidget *window,
+				   GdkEventAny *event,
+				   gpointer data)
+{
+	gtk_widget_hide (window);
+
+	return TRUE;
+}
+
+static void
+totem_plugins_response_cb (GtkDialog *dialog,
+			      int response_id,
+			      gpointer data)
+{
+	gtk_widget_hide (GTK_WIDGET (dialog));
+}
+
+static void
+plugin_button_clicked_cb (GtkButton *button,
+			  Totem     *totem)
+{
+	if (totem->plugins == NULL) {
+		GtkWidget *manager;
+
+		totem->plugins = gtk_dialog_new_with_buttons (_("Configure Plugins"),
+							      GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (button))),
+							      GTK_DIALOG_DESTROY_WITH_PARENT,
+							      _("_Close"),
+							      GTK_RESPONSE_CLOSE,
+							      NULL);
+		gtk_container_set_border_width (GTK_CONTAINER (totem->plugins), 5);
+		gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (totem->plugins))), 2);
+
+		g_signal_connect_object (G_OBJECT (totem->plugins),
+					 "delete_event",
+					 G_CALLBACK (totem_plugins_window_delete_cb),
+					 NULL, 0);
+		g_signal_connect_object (G_OBJECT (totem->plugins),
+					 "response",
+					 G_CALLBACK (totem_plugins_response_cb),
+					 NULL, 0);
+
+		manager = peas_gtk_plugin_manager_new (NULL);
+		gtk_widget_show_all (GTK_WIDGET (manager));
+		gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (totem->plugins))),
+				    manager, TRUE, TRUE, 0);
+		gtk_window_set_default_size (GTK_WINDOW (totem->plugins), 600, 400);
+	}
+
+	gtk_window_present (GTK_WINDOW (totem->plugins));
+}
+
 void
 totem_setup_preferences (Totem *totem)
 {
-	GtkWidget *menu, *content_area, *bvw;
-	gboolean show_visuals, lock_screensaver_on_audio;
+	GtkWidget *menu, *bvw;
+	gboolean show_visuals;
 	guint i, hidden;
 	char *visual, *font, *encoding;
 	GList *list, *l;
-	GtkWidget *widget;
 	GObject *item;
 
 	static struct {
@@ -289,25 +310,9 @@ totem_setup_preferences (Totem *totem)
 
 	g_return_if_fail (totem->settings != NULL);
 
-	bvw = totem_get_video_widget (totem);
-
-	/* Work-around builder dialogue not parenting properly for
-	 * On top windows */
-	widget = PWID ("tpw_notebook");
-	totem->prefs = gtk_dialog_new_with_buttons (_("Preferences"),
-			GTK_WINDOW (totem->win),
-			GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_STOCK_CLOSE,
-			GTK_RESPONSE_ACCEPT,
-			NULL);
-	gtk_container_set_border_width (GTK_CONTAINER (totem->prefs), 5);
-	content_area = gtk_dialog_get_content_area (GTK_DIALOG (totem->prefs));
-	gtk_box_set_spacing (GTK_BOX (content_area), 2);
-	gtk_widget_reparent (widget, content_area);
-	gtk_widget_show_all (content_area);
-	widget = PWID ("totem_preferences_window");
-	gtk_widget_destroy (widget);
+	bvw = totem_object_get_video_widget (totem);
 
+	totem->prefs = PWID ("totem_preferences_window");
 	g_signal_connect (G_OBJECT (totem->prefs), "response",
 			G_CALLBACK (gtk_widget_hide), NULL);
 	g_signal_connect (G_OBJECT (totem->prefs), "delete-event",
@@ -315,25 +320,6 @@ totem_setup_preferences (Totem *totem)
         g_signal_connect (totem->prefs, "destroy",
                           G_CALLBACK (gtk_widget_destroyed), &totem->prefs);
 
-	/* Remember position */
-	item = POBJ ("tpw_remember_position_checkbutton");
-	g_settings_bind (totem->settings, "remember-position", item, "active", G_SETTINGS_BIND_DEFAULT);
-	g_settings_bind (totem->settings, "remember-position", totem, "remember-position", G_SETTINGS_BIND_DEFAULT | G_SETTINGS_BIND_NO_SENSITIVITY);
-
-	/* Auto-resize */
-	item = POBJ ("tpw_display_checkbutton");
-	g_settings_bind (totem->settings, "auto-resize", item, "active", G_SETTINGS_BIND_DEFAULT);
-	g_settings_bind (totem->settings, "auto-resize", bvw, "auto-resize", G_SETTINGS_BIND_DEFAULT | G_SETTINGS_BIND_NO_SENSITIVITY);
-
-	/* Screensaver audio locking */
-	lock_screensaver_on_audio = g_settings_get_boolean (totem->settings, "lock-screensaver-on-audio");
-	if (lock_screensaver_on_audio != FALSE)
-		item = POBJ ("tpw_audio_toggle_button");
-	else
-		item = POBJ ("tpw_video_toggle_button");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), TRUE);
-	g_signal_connect (totem->settings, "changed::lock-screensaver-on-audio", (GCallback) lock_screensaver_on_audio_changed_cb, totem);
-
 	/* Disable deinterlacing */
 	item = POBJ ("tpw_no_deinterlace_checkbutton");
 	g_settings_bind (totem->settings, "disable-deinterlacing", item, "active", G_SETTINGS_BIND_DEFAULT);
@@ -360,6 +346,11 @@ totem_setup_preferences (Totem *totem)
 	item = POBJ ("tpw_auto_chapters_checkbutton");
 	g_settings_bind (totem->settings, "autoload-chapters", item, "active", G_SETTINGS_BIND_DEFAULT);
 
+	/* Plugins button */
+	item = POBJ ("tpw_plugins_button");
+	g_signal_connect (G_OBJECT (item), "clicked",
+			  G_CALLBACK (plugin_button_clicked_cb), totem);
+
 	/* Visuals list */
 	list = bacon_video_widget_get_visualization_list (totem->bvw);
 	menu = gtk_menu_new ();
