@@ -33,8 +33,8 @@
 
 #include "totem-playlist.h"
 #include "backend/bacon-video-widget.h"
+#include "backend/bacon-time-label.h"
 #include "totem-open-location.h"
-#include "totem-fullscreen.h"
 #include "totem-plugins-engine.h"
 
 #define totem_signal_block_by_data(obj, data) (g_signal_handlers_block_matched (obj, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, data))
@@ -46,19 +46,25 @@
 		widget = GTK_WIDGET (gtk_builder_get_object (xml, name));	\
 		gtk_widget_set_sensitive (widget, state);			\
 	}
-#define totem_main_set_sensitivity(name, state) totem_set_sensitivity (totem->xml, name, state)
+#define totem_controls_set_sensitivity(name, state) gtk_widget_set_sensitive (g_object_get_data (totem->controls, name), state)
 
-#define totem_action_set_sensitivity(name, state)					\
+#define totem_object_set_sensitivity(name, state)					\
 	{										\
 		GtkAction *__action;							\
 		__action = gtk_action_group_get_action (totem->main_action_group, name);\
 		gtk_action_set_sensitive (__action, state);				\
 	}
 
+#define totem_object_set_sensitivity2(name, state)					\
+	{										\
+		GAction *__action;							\
+		__action = g_action_map_lookup_action (G_ACTION_MAP (totem), name);	\
+		g_simple_action_set_enabled (G_SIMPLE_ACTION (__action), state);	\
+	}
+
 typedef enum {
 	TOTEM_CONTROLS_UNDEFINED,
 	TOTEM_CONTROLS_VISIBLE,
-	TOTEM_CONTROLS_HIDDEN,
 	TOTEM_CONTROLS_FULLSCREEN
 } ControlsVisibility;
 
@@ -74,18 +80,25 @@ struct _TotemObject {
 	/* Control window */
 	GtkBuilder *xml;
 	GtkWidget *win;
+	GtkWidget *stack;
 	BaconVideoWidget *bvw;
 	GtkWidget *prefs;
 	GtkBuilder *prefs_xml;
-	GtkWidget *statusbar;
+
+	GtkWidget *grilo;
+
+	GObject *controls;
+	BaconTimeLabel *time_label;
+	BaconTimeLabel *time_rem_label;
+	GtkWidget *header;
+
+	GtkWidget *revealer;
+	GtkWidget *fullscreen_header;
 
 	/* UI manager */
 	GtkActionGroup *main_action_group;
 	GtkUIManager *ui_manager;
 
-	GtkActionGroup *devices_action_group;
-	guint devices_ui_id;
-
 	GtkActionGroup *languages_action_group;
 	guint languages_ui_id;
 
@@ -96,11 +109,6 @@ struct _TotemObject {
 	GtkWidget *plugins;
 	TotemPluginsEngine *engine;
 
-	/* Sidebar */
-	GtkWidget *sidebar;
-	gboolean sidebar_shown;
-	int sidebar_w;
-
 	/* Seek */
 	GtkWidget *seek;
 	GtkAdjustment *seekadj;
@@ -114,13 +122,9 @@ struct _TotemObject {
 	double prev_volume;
 
 	/* Subtitles/Languages menus */
-	GtkWidget *subtitles;
-	GtkWidget *languages;
+	gboolean updating_menu;
 	GList *subtitles_list;
-	GList *language_list;
-
-	/* Fullscreen */
-	TotemFullscreen *fs;
+	GList *languages_list;
 
 	/* controls management */
 	ControlsVisibility controls_visibility;
@@ -128,33 +132,35 @@ struct _TotemObject {
 	/* Stream info */
 	gint64 stream_length;
 
-	/* recent file stuff */
-	GtkRecentManager *recent_manager;
-	GtkActionGroup *recent_action_group;
-	guint recent_ui_id;
-
 	/* Monitor for playlist unmounts and drives/volumes monitoring */
 	GVolumeMonitor *monitor;
 	gboolean drives_changed;
 
 	/* session */
-	const char *argv0;
 	gint64 seek_to_start;
-	guint index;
-	gboolean session_restored;
+	guint save_timeout_id;
 
 	/* Window State */
 	int window_w, window_h;
 	gboolean maximised;
 
+	/* Toolbar state */
+	char *title;
+	char *subtitle;
+	char *search_string;
+	gboolean select_mode;
+	GObject *custom_title;
+	GtkWidget *fullscreen_button;
+	GtkWidget *gear_button;
+
+	char *player_title;
+
 	/* other */
 	char *mrl;
-	gint64 seek_to;
 	TotemPlaylist *playlist;
 	GSettings *settings;
 	TotemStates state;
 	TotemOpenLocation *open_location;
-	gboolean remember_position;
 	gboolean disable_kbd_shortcuts;
 	gboolean has_played_emitted;
 };
@@ -173,20 +179,36 @@ GtkWidget *totem_volume_create (void);
 #define ZOOM_IN_OFFSET 0.01
 #define ZOOM_OUT_OFFSET -0.01
 
-void	totem_action_open			(Totem *totem);
-void	totem_action_open_location		(Totem *totem);
-void	totem_action_eject			(Totem *totem);
-void	totem_action_set_zoom			(Totem *totem, gboolean zoom);
-void	totem_action_show_help			(Totem *totem);
-void	totem_action_show_properties		(Totem *totem);
-gboolean totem_action_open_files		(Totem *totem, char **list);
-G_GNUC_NORETURN void totem_action_error_and_exit (const char *title, const char *reason, Totem *totem);
+void	totem_object_open			(Totem *totem);
+void	totem_object_open_location		(Totem *totem);
+void	totem_object_eject			(Totem *totem);
+void	totem_object_set_zoom			(Totem *totem, gboolean zoom);
+void	totem_object_show_help			(Totem *totem);
+void	totem_object_show_properties		(Totem *totem);
+void    totem_object_set_mrl			(TotemObject *totem,
+						 const char *mrl,
+						 const char *subtitle);
+gboolean totem_object_open_files		(Totem *totem, char **list);
+G_GNUC_NORETURN void totem_object_show_error_and_exit (const char *title, const char *reason, Totem *totem);
 
 void	show_controls				(Totem *totem, gboolean was_fullscreen);
 
-char	*totem_setup_window			(Totem *totem);
+void	totem_setup_window			(Totem *totem);
 void	totem_callback_connect			(Totem *totem);
 void	playlist_widget_setup			(Totem *totem);
+void	grilo_widget_setup			(Totem *totem);
 void	video_widget_create			(Totem *totem);
+void    totem_object_plugins_init		(TotemObject *totem);
+void    totem_object_plugins_shutdown		(TotemObject *totem);
+void	totem_object_set_fullscreen		(TotemObject *totem, gboolean state);
+void	totem_object_set_volume_relative	(TotemObject *totem, double off_pct);
+void	totem_object_volume_toggle_mute		(TotemObject *totem);
+void	totem_object_set_main_page		(TotemObject *totem,
+						 const char  *page_id);
+const char * totem_object_get_main_page		(Totem *totem);
+
+/* Signal emission */
+void	totem_file_has_played			(TotemObject *totem,
+						 const char *mrl);
 
 #endif /* __TOTEM_PRIVATE_H__ */
