@@ -30,10 +30,10 @@
 #define GST_USE_UNSTABLE_API 1
 
 #include <glib/gstdio.h>
-#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <cairo.h>
 #include <gst/gst.h>
+#include <gdk/gdk.h>
 #include <totem-pl-parser.h>
 
 #include <errno.h>
@@ -48,7 +48,6 @@
 #include "gst/totem-gst-helpers.h"
 #include "gst/totem-time-helpers.h"
 #include "gst/totem-gst-pixbuf-helpers.h"
-#include "video-utils.h"
 #include "totem-resources.h"
 
 #ifdef G_HAVE_ISO_VARARGS
@@ -183,6 +182,39 @@ error_handler (GstBus *bus,
 	case GST_MESSAGE_EOS:
 		exit (0);
 
+	case GST_MESSAGE_ASYNC_DONE:
+	case GST_MESSAGE_UNKNOWN:
+	case GST_MESSAGE_WARNING:
+	case GST_MESSAGE_INFO:
+	case GST_MESSAGE_TAG:
+	case GST_MESSAGE_BUFFERING:
+	case GST_MESSAGE_STATE_CHANGED:
+	case GST_MESSAGE_STATE_DIRTY:
+	case GST_MESSAGE_STEP_DONE:
+	case GST_MESSAGE_CLOCK_PROVIDE:
+	case GST_MESSAGE_CLOCK_LOST:
+	case GST_MESSAGE_NEW_CLOCK:
+	case GST_MESSAGE_STRUCTURE_CHANGE:
+	case GST_MESSAGE_STREAM_STATUS:
+	case GST_MESSAGE_APPLICATION:
+	case GST_MESSAGE_ELEMENT:
+	case GST_MESSAGE_SEGMENT_START:
+	case GST_MESSAGE_SEGMENT_DONE:
+	case GST_MESSAGE_DURATION_CHANGED:
+	case GST_MESSAGE_LATENCY:
+	case GST_MESSAGE_ASYNC_START:
+	case GST_MESSAGE_REQUEST_STATE:
+	case GST_MESSAGE_STEP_START:
+	case GST_MESSAGE_QOS:
+	case GST_MESSAGE_PROGRESS:
+	case GST_MESSAGE_TOC:
+	case GST_MESSAGE_RESET_TIME:
+	case GST_MESSAGE_STREAM_START:
+	case GST_MESSAGE_ANY:
+#if GST_CHECK_VERSION (1, 1, 3)
+	case GST_MESSAGE_NEED_CONTEXT:
+	case GST_MESSAGE_HAVE_CONTEXT:
+#endif
 	default:
 		/* Ignored */
 		;;
@@ -195,8 +227,7 @@ static void
 thumb_app_cleanup (ThumbApp *app)
 {
 	gst_element_set_state (app->play, GST_STATE_NULL);
-	g_object_unref (app->play);
-	app->play = NULL;
+	g_clear_object (&app->play);
 }
 
 static void
@@ -306,6 +337,39 @@ thumb_app_start (ThumbApp *app)
 			terminate = TRUE;
 			break;
 
+		case GST_MESSAGE_UNKNOWN:
+		case GST_MESSAGE_EOS:
+		case GST_MESSAGE_WARNING:
+		case GST_MESSAGE_INFO:
+		case GST_MESSAGE_TAG:
+		case GST_MESSAGE_BUFFERING:
+		case GST_MESSAGE_STATE_CHANGED:
+		case GST_MESSAGE_STATE_DIRTY:
+		case GST_MESSAGE_STEP_DONE:
+		case GST_MESSAGE_CLOCK_PROVIDE:
+		case GST_MESSAGE_CLOCK_LOST:
+		case GST_MESSAGE_NEW_CLOCK:
+		case GST_MESSAGE_STRUCTURE_CHANGE:
+		case GST_MESSAGE_STREAM_STATUS:
+		case GST_MESSAGE_APPLICATION:
+		case GST_MESSAGE_ELEMENT:
+		case GST_MESSAGE_SEGMENT_START:
+		case GST_MESSAGE_SEGMENT_DONE:
+		case GST_MESSAGE_DURATION_CHANGED:
+		case GST_MESSAGE_LATENCY:
+		case GST_MESSAGE_ASYNC_START:
+		case GST_MESSAGE_REQUEST_STATE:
+		case GST_MESSAGE_STEP_START:
+		case GST_MESSAGE_QOS:
+		case GST_MESSAGE_PROGRESS:
+		case GST_MESSAGE_TOC:
+		case GST_MESSAGE_RESET_TIME:
+		case GST_MESSAGE_STREAM_START:
+		case GST_MESSAGE_ANY:
+#if GST_CHECK_VERSION (1, 1, 3)
+		case GST_MESSAGE_NEED_CONTEXT:
+		case GST_MESSAGE_HAVE_CONTEXT:
+#endif
 		default:
 			/* Ignore */
 			;;
@@ -685,12 +749,8 @@ capture_interesting_frame (ThumbApp *app)
 
 		/* If we get to the end of this loop, we'll end up using
 		 * the last image we pulled */
-		if (current + 1 < G_N_ELEMENTS(frame_locations)) {
-			if (pixbuf != NULL) {
-				g_object_unref (pixbuf);
-				pixbuf = NULL;
-			}
-		}
+		if (current + 1 < G_N_ELEMENTS(frame_locations))
+			g_clear_object (&pixbuf);
 		PROGRESS_DEBUG("Frame for iter %d was not interesting", current);
 	}
 	return pixbuf;
@@ -745,6 +805,7 @@ create_gallery (ThumbApp *app)
 	gint screenshot_width = 0, screenshot_height = 0, x_padding = 0, y_padding = 0;
 	gfloat scale = 1.0;
 	gchar *header_text, *duration_text, *filename;
+	GFile *file;
 
 	/* Calculate how many screenshots we're going to take */
 	stream_length = app->duration;
@@ -860,16 +921,10 @@ create_gallery (ThumbApp *app)
 	g_object_unref (pixbuf);
 
 	/* Build the header information */
-	duration_text = totem_time_to_string (stream_length);
-	filename = NULL;
-	if (strstr (app->input, "://")) {
-		char *local;
-		local = g_filename_from_uri (app->input, NULL, NULL);
-		filename = g_path_get_basename (local);
-		g_free (local);
-	}
-	if (filename == NULL)
-		filename = g_path_get_basename (app->input);
+	duration_text = totem_time_to_string (stream_length, FALSE, FALSE);
+	file = g_file_new_for_commandline_arg (app->input);
+	filename = g_file_get_basename (file);
+	g_object_unref (file);
 
 	/* Translators: The first string is "Filename" (as translated); the second is an actual filename.
 			The third string is "Resolution" (as translated); the fourth and fifth are screenshot height and width, respectively.
@@ -915,7 +970,7 @@ create_gallery (ThumbApp *app)
 		gchar *timestamp_text;
 		gint layout_width, layout_height;
 
-		timestamp_text = totem_time_to_string (pos);
+		timestamp_text = totem_time_to_string (pos, FALSE, FALSE);
 
 		pango_layout_set_text (layout, timestamp_text, -1);
 		pango_layout_get_pixel_size (layout, &layout_width, &layout_height);
@@ -987,7 +1042,6 @@ int main (int argc, char *argv[])
 	options = gst_init_get_option_group ();
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, options);
-	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 
 	if (g_option_context_parse (context, &argc, &argv, &err) == FALSE) {
 		g_print ("couldn't parse command-line options: %s\n", err->message);
