@@ -45,12 +45,11 @@
 #include "totem-interface.h"
 #include "totem-options.h"
 #include "totem-menu.h"
-#include "totem-session.h"
 #include "totem-uri.h"
 #include "totem-preferences.h"
-#include "totem-rtl-helpers.h"
-#include "totem-sidebar.h"
+#include "totem-session.h"
 #include "video-utils.h"
+#include "totem-rtl-helpers.h"
 
 static gboolean startup_called = FALSE;
 
@@ -86,7 +85,6 @@ static void
 app_init (Totem *totem, char **argv)
 {
 	GtkSettings *gtk_settings;
-	char *sidebar_pageid;
 
 	if (gtk_clutter_init (NULL, NULL) != CLUTTER_INIT_SUCCESS)
 		g_warning ("gtk-clutter failed to initialise, expect problems from here on.");
@@ -100,20 +98,16 @@ app_init (Totem *totem, char **argv)
 	/* Main window */
 	totem->xml = totem_interface_load ("totem.ui", TRUE, NULL, totem);
 	if (totem->xml == NULL)
-		totem_action_exit (NULL);
+		totem_object_exit (NULL);
 
 	set_rtl_icon_name (totem, "play", "media-playback-start");
 	set_rtl_icon_name (totem, "next-chapter", "media-skip-forward");
 	set_rtl_icon_name (totem, "previous-chapter", "media-skip-backward");
-	set_rtl_icon_name (totem, "skip-forward", "media-seek-forward");
-	set_rtl_icon_name (totem, "skip-backwards", "media-seek-backward");
 
 	totem->win = GTK_WIDGET (gtk_builder_get_object (totem->xml, "totem_main_window"));
-	g_object_bind_property (G_OBJECT (totem), "fullscreen",
-				G_OBJECT (totem->win), "show-menubar",
-				G_BINDING_INVERT_BOOLEAN);
 
 	/* Menubar */
+	totem->stack = GTK_WIDGET (gtk_builder_get_object (totem->xml, "tmw_main_stack"));
 	totem_ui_manager_setup (totem);
 
 	/* The sidebar */
@@ -121,43 +115,44 @@ app_init (Totem *totem, char **argv)
 
 	/* The rest of the widgets */
 	totem->state = STATE_STOPPED;
-	totem->seek = GTK_WIDGET (gtk_builder_get_object (totem->xml, "tmw_seek_hscale"));
-	totem->seekadj = gtk_range_get_adjustment (GTK_RANGE (totem->seek));
-	totem->volume = GTK_WIDGET (gtk_builder_get_object (totem->xml, "tmw_volume_button"));
-	totem->statusbar = GTK_WIDGET (gtk_builder_get_object (totem->xml, "tmw_statusbar"));
-	totem->seek_lock = FALSE;
-	totem->fs = totem_fullscreen_new (GTK_WINDOW (totem->win));
-	gtk_scale_button_set_adjustment (GTK_SCALE_BUTTON (totem->fs->volume),
-					 gtk_scale_button_get_adjustment (GTK_SCALE_BUTTON (totem->volume)));
-	gtk_range_set_adjustment (GTK_RANGE (totem->fs->seek), totem->seekadj);
 
-	totem_session_setup (totem, argv);
+	totem->seek_lock = FALSE;
+
 	totem_setup_file_monitoring (totem);
 	totem_setup_file_filters ();
 	totem_app_menu_setup (totem);
-	totem_callback_connect (totem);
+	/* totem_callback_connect (totem); XXX we do this later now, so it might look ugly for a short while */
 
-	sidebar_pageid = totem_setup_window (totem);
+	totem_setup_window (totem);
+
+	/* Show ! (again) the video widget this time. */
+	video_widget_create (totem);
+	grilo_widget_setup (totem);
 
 	/* Show ! */
 	if (optionstate.fullscreen == FALSE) {
 		gtk_widget_show (totem->win);
-		totem_gdk_window_set_waiting_cursor (gtk_widget_get_window (totem->win));
+		g_application_mark_busy (G_APPLICATION (totem));
 	} else {
 		gtk_widget_realize (totem->win);
 	}
 
 	totem->controls_visibility = TOTEM_CONTROLS_UNDEFINED;
 
-	/* Show ! (again) the video widget this time. */
-	video_widget_create (totem);
+	totem->seek = g_object_get_data (totem->controls, "seek_scale");
+	totem->seekadj = gtk_range_get_adjustment (GTK_RANGE (totem->seek));
+	totem->volume = g_object_get_data (totem->controls, "volume_button");
+	totem->time_label = g_object_get_data (totem->controls, "time_label");
+	totem->time_rem_label = g_object_get_data (totem->controls, "time_rem_label");
+
+	totem_callback_connect (totem);
+
 	gtk_widget_grab_focus (GTK_WIDGET (totem->bvw));
-	totem_fullscreen_set_video_widget (totem->fs, totem->bvw);
 
 	if (optionstate.fullscreen != FALSE) {
 		gtk_widget_show (totem->win);
 		gdk_flush ();
-		totem_action_fullscreen (totem, TRUE);
+		totem_object_set_fullscreen (totem, TRUE);
 	}
 
 	/* The prefs after the video widget is connected */
@@ -165,37 +160,32 @@ app_init (Totem *totem, char **argv)
 
 	totem_setup_preferences (totem);
 
-	totem_setup_recent (totem);
-
-	/* Command-line handling */
-	totem_options_process_late (totem, &optionstate);
-
 	/* Initialise all the plugins, and set the default page, in case
 	 * it comes from a plugin */
 	totem_object_plugins_init (totem);
-	totem_sidebar_set_current_page (totem, sidebar_pageid, FALSE);
-	g_free (sidebar_pageid);
 
-	if (totem->session_restored != FALSE) {
-		totem_session_restore (totem, optionstate.filenames);
-	} else if (optionstate.filenames != NULL && totem_action_open_files (totem, optionstate.filenames)) {
-		totem_action_play_pause (totem);
+	if (optionstate.filenames == NULL) {
+		if (totem_session_try_restore (totem) == FALSE)
+			totem_object_set_mrl (totem, NULL, NULL);
 	} else {
-		totem_action_set_mrl (totem, NULL, NULL);
+		if (totem_object_open_files (totem, optionstate.filenames))
+			totem_object_play_pause (totem);
+		else
+			totem_object_set_mrl (totem, NULL, NULL);
 	}
 
 	/* Set the logo at the last minute so we won't try to show it before a video */
 	bacon_video_widget_set_logo (totem->bvw, "totem");
 
 	if (optionstate.fullscreen == FALSE)
-		gdk_window_set_cursor (gtk_widget_get_window (totem->win), NULL);
+		g_application_unmark_busy (G_APPLICATION (totem));
 
 	gtk_window_set_application (GTK_WINDOW (totem->win), GTK_APPLICATION (totem));
 }
 
 static void
 app_startup (GApplication *application,
-		Totem        *totem)
+	     Totem        *totem)
 {
 	/* We don't do anything here, as we need to know the options
 	 * when we set everything up.
@@ -236,8 +226,7 @@ app_command_line (GApplication             *app,
 		gdk_notify_startup_complete ();
 
 		/* Don't add files again through totem_options_process_for_server() */
-		g_strfreev (optionstate.filenames);
-		optionstate.filenames = NULL;
+		g_clear_pointer (&optionstate.filenames, g_strfreev);
 		startup_called = FALSE;
 	}
 
@@ -263,12 +252,10 @@ main (int argc, char **argv)
 	{
 		gtk_init (&argc, &argv);
 		g_set_application_name (_("Videos"));
-		totem_action_error_and_exit (_("Could not initialize the thread-safe libraries."), _("Verify your system installation. Totem will now exit."), NULL);
+		totem_object_show_error_and_exit (_("Could not initialize the thread-safe libraries."), _("Verify your system installation. Totem will now exit."), NULL);
 	}
 #endif
 
-	g_type_init ();
-
 	g_set_prgname ("totem");
 	g_set_application_name (_("Videos"));
 	gtk_window_set_default_icon_name ("totem");
